@@ -853,6 +853,9 @@ static int health_readfile(const char *filename, void *data) {
 }
 
 void health_readdir(RRDHOST *host, const char *user_path, const char *stock_path, const char *subpath) {
-    if(unlikely(!host->health_enabled)) return;
+    if(unlikely(!host->health_enabled)) {
+        debug(D_HEALTH, "CONFIG health is not enabled for host '%s'", host->hostname);
+        return;
+    }
     recursive_config_double_dir_load(user_path, stock_path, subpath, health_readfile, (void *) host, 0);
 }
