@@ -81,6 +81,8 @@ static int registry_json_person_url_callback(void *entry, void *data) {
     struct registry_json_walk_person_urls_callback *c = (struct registry_json_walk_person_urls_callback *)data;
     struct web_client *w = c->w;
 
+    if (!strcmp(pu->url->url,"***")) return 0;
+    
     if(unlikely(c->count++))
         buffer_strcat(w->response.data, ",");
 
@@ -97,6 +99,8 @@ static int registry_json_machine_url_callback(void *entry, void *data) {
     struct web_client *w = c->w;
     REGISTRY_MACHINE *m = c->m;
 
+    if (!strcmp(mu->url->url,"***")) return 1;
+
     if(unlikely(c->count++))
         buffer_strcat(w->response.data, ",");
 
@@ -131,8 +135,10 @@ static inline int registry_person_url_callback_verify_machine_exists(void *entry
 int registry_request_hello_json(RRDHOST *host, struct web_client *w) {
     registry_json_header(host, w, "hello", REGISTRY_STATUS_OK);
 
-    buffer_sprintf(w->response.data, ",\n\t\"registry\": \"%s\"",
-            registry.registry_to_announce);
+    buffer_sprintf(w->response.data,
+            ",\n\t\"registry\": \"%s\",\n\t\"cloud_base_url\": \"%s\",\n\t\"anonymous_statistics\": %s",
+            registry.registry_to_announce,
+            registry.cloud_base_url, netdata_anonymous_statistics_enabled?"true":"false");
 
     registry_json_footer(w);
     return 200;
@@ -332,7 +338,7 @@ void registry_statistics(void) {
                 , "registry"
                 , NULL
                 , "NetData Registry Sessions"
-                , "session"
+                , "sessions"
                 , "registry"
                 , "stats"
                 , 131000
@@ -390,7 +396,7 @@ void registry_statistics(void) {
                 , "registry"
                 , NULL
                 , "NetData Registry Memory"
-                , "KB"
+                , "KiB"
                 , "registry"
                 , "stats"
                 , 131300
